@@ -2,12 +2,10 @@ package Module::Install::Admin::Bundle;
 
 use strict;
 use Module::Install::Base;
-use Module::CoreList;
-use LWP::UserAgent;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.06';
+	$VERSION = '1.10';
 	@ISA     = qw{Module::Install::Base};
 }
 
@@ -73,3 +71,20 @@ sub bundle {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 COPYRIGHT
+
+Copyright 2008 - 2014 Adam Kennedy.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
