@@ -5,7 +5,7 @@ use File::Find ();
 use Module::Install::Base ();
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.06';
+	$VERSION = '1.10';
 	@ISA = qw(Module::Install::Base);
 }
 
@@ -75,3 +75,20 @@ sub find_files {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 COPYRIGHT
+
+Copyright 2008 - 2014 Adam Kennedy.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
