@@ -9,7 +9,7 @@ use Config;
 
 use vars qw{$VERSION @ISA @EXPORT $DIST};
 BEGIN {
-	$VERSION = '1.08';
+	$VERSION = '1.10';
 	@ISA     = 'Exporter';
 	@EXPORT  = qw{
 		create_dist
@@ -189,10 +189,17 @@ sub run_makefile_pl {
 sub kill_dist {
 	my $dir = dir();
 	return 1 unless -d $dir;
+	windows_delay();
 	File::Remove::remove( \1, $dir );
+	windows_delay();
 	return -d $dir ? 0 : 1;
 }
 
+sub windows_delay {
+	return if $^O ne 'MSWin32';
+	select undef, undef, undef, 0.1;
+}
+
 sub supports_capture {
 	# stolen from ExtUtils::MakeMaker's test
 	use ExtUtils::MM;
